mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Yuyang Du <yuyang.du@intel.com>
To: mingo@kernel.org, peterz@infradead.org, linux-kernel@vger.kernel.org
Cc: pjt@google.com, bsegall@google.com, morten.rasmussen@arm.com,
	vincent.guittot@linaro.org, dietmar.eggemann@arm.com,
	arjan.van.de.ven@intel.com, len.brown@intel.com,
	fengguang.wu@intel.com, Yuyang Du <yuyang.du@intel.com>
Subject: [PATCH v7 3/4] sched: Init cfs_rq's sched_entity load average
Date: Thu, 14 May 2015 10:22:14 +0800	[thread overview]
Message-ID: <1431570135-12838-4-git-send-email-yuyang.du@intel.com> (raw)
In-Reply-To: <1431570135-12838-1-git-send-email-yuyang.du@intel.com>

The runnable load and utilization averages of cfs_rq's sched_entity were
not initiated. Like done to a task, give new cfs_rq' sched_entity
start values to heavy its load in infant time.

Signed-off-by: Yuyang Du <yuyang.du@intel.com>
---
 kernel/sched/core.c  |    2 +-
 kernel/sched/fair.c  |   13 +++++++------
 kernel/sched/sched.h |    2 +-
 3 files changed, 9 insertions(+), 8 deletions(-)

diff --git a/kernel/sched/core.c b/kernel/sched/core.c
index b4e6c21..f46992f 100644
--- a/kernel/sched/core.c
+++ b/kernel/sched/core.c
@@ -2102,7 +2102,7 @@ void wake_up_new_task(struct task_struct *p)
 #endif
 
 	/* Initialize new task's runnable average */
-	init_task_runnable_average(p);
+	init_entity_runnable_average(&p->se);
 	rq = __task_rq_lock(p);
 	activate_task(rq, p, 0);
 	p->on_rq = TASK_ON_RQ_QUEUED;
diff --git a/kernel/sched/sched.h b/kernel/sched/sched.h
index 13ff009..08c9647 100644
--- a/kernel/sched/sched.h
+++ b/kernel/sched/sched.h
@@ -1288,7 +1288,7 @@ unsigned long to_ratio(u64 period, u64 runtime);
 
 extern void update_idle_cpu_load(struct rq *this_rq);
 
-extern void init_task_runnable_average(struct task_struct *p);
+extern void init_entity_runnable_average(struct sched_entity *se);
 
 static inline void add_nr_running(struct rq *rq, unsigned count)
 {
diff --git a/kernel/sched/fair.c b/kernel/sched/fair.c
index 2a87012..962d40d 100644
--- a/kernel/sched/fair.c
+++ b/kernel/sched/fair.c
@@ -672,10 +672,10 @@ static unsigned long task_h_load(struct task_struct *p);
 #define LOAD_AVG_MAX 47742 /* maximum possible load avg */
 #define LOAD_AVG_MAX_N 345 /* number of full periods to produce LOAD_MAX_AVG */
 
-/* Give new task start runnable values to heavy its load in infant time */
-void init_task_runnable_average(struct task_struct *p)
+/* Give new sched_entity start runnable values to heavy its load in infant time */
+void init_entity_runnable_average(struct sched_entity *se)
 {
-	struct sched_avg *sa = &p->se.avg;
+	struct sched_avg *sa = &se->avg;
 
 	sa->last_update_time = 0;
 	/*
@@ -684,14 +684,14 @@ void init_task_runnable_average(struct task_struct *p)
 	 * will definitely be update (after enqueue).
 	 */
 	sa->period_contrib = 1023;
-	sa->load_avg = p->se.load.weight;
-	sa->load_sum = p->se.load.weight * LOAD_AVG_MAX;
+	sa->load_avg = se->load.weight;
+	sa->load_sum = se->load.weight * LOAD_AVG_MAX;
 	sa->util_avg = SCHED_LOAD_SCALE;
 	sa->util_sum = SCHED_LOAD_SCALE * LOAD_AVG_MAX;
 	/* when this task enqueue'ed, it will contribute to its cfs_rq's load_avg */
 }
 #else
-void init_task_runnable_average(struct task_struct *p)
+void init_entity_runnable_average(struct sched_entity *se)
 {
 }
 #endif
@@ -7854,6 +7854,7 @@ int alloc_fair_sched_group(struct task_group *tg, struct task_group *parent)
 
 		init_cfs_rq(cfs_rq);
 		init_tg_cfs_entry(tg, cfs_rq, se, i, parent->se[i]);
+		init_entity_runnable_average(se);
 	}
 
 	return 1;
-- 
1.7.9.5


  parent reply	other threads:[~2015-05-14 10:16 UTC|newest]

Thread overview: 7+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2015-05-14  2:22 [PATCH v7 0/4] sched: Rewrite runnable load and utilization average tracking Yuyang Du
2015-05-14  2:22 ` [PATCH v7 1/4] sched: Remove rq's runnable avg Yuyang Du
2015-05-14  2:22 ` [PATCH v7 2/4] sched: Rewrite runnable load and utilization average tracking Yuyang Du
2015-05-18 20:55   ` bsegall
2015-05-19  8:09     ` Yuyang Du
2015-05-14  2:22 ` Yuyang Du [this message]
2015-05-14  2:22 ` [PATCH v7 4/4] sched: Remove task and group entity load when they are dead Yuyang Du

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1431570135-12838-4-git-send-email-yuyang.du@intel.com \
    --to=yuyang.du@intel.com \
    --cc=arjan.van.de.ven@intel.com \
    --cc=bsegall@google.com \
    --cc=dietmar.eggemann@arm.com \
    --cc=fengguang.wu@intel.com \
    --cc=len.brown@intel.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=mingo@kernel.org \
    --cc=morten.rasmussen@arm.com \
    --cc=peterz@infradead.org \
    --cc=pjt@google.com \
    --cc=vincent.guittot@linaro.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®